@@ -267,18 +267,28 @@ class AbstractRetrieval(Retrieval):
     @property
     def funding(self) -> Optional[List[NamedTuple]]:
         """List of namedtuples parsed funding information in the form
-        (agency string id acronym country).
+        (agency, agency_id, string, funding_id, acronym, country).
         """
+
+        def _get_funding_id(f_dict: dict) -> list:
+            funding_get = f_dict.get('xocs:funding-id', [])
+            try:
+                return [v['$'] for v in funding_get] or None  # multiple or empty
+            except TypeError:
+                return [funding_get]  # single
+
         path = ['item', 'xocs:meta', 'xocs:funding-list', 'xocs:funding']
         funds = listify(chained_get(self._json, path, []))
         out = []
-        fund = namedtuple('Funding', 'agency string id acronym country')
+        fields = 'agency agency_id string funding_id acronym country'
+        fund = namedtuple('Funding', fields)
         for item in funds:
             new = fund(agency=item.get('xocs:funding-agency'),
-                string=item.get('xocs:funding-agency-matched-string'),
-                id=item.get('xocs:funding-agency-id'),
-                acronym=item.get('xocs:funding-agency-acronym'),
-                country=item.get('xocs:funding-agency-country'))
+                       agency_id=item.get('xocs:funding-agency-id'),
+                       string=item.get('xocs:funding-agency-matched-string'),
+                       funding_id=_get_funding_id(item),
+                       acronym=item.get('xocs:funding-agency-acronym'),
+                       country=item.get('xocs:funding-agency-country'))
             out.append(new)
         return out or None
 
